===========================================
BooruPy
===========================================

BooruPy is a simple library for interacting with various image board "Booru" systems. 

Supporting
----------

* Danbooru
* Gelbooru 0.2+ (0.1.X has no API support)

Applications using BooruPy
--------------------------

* BooruPyLoadr_

License
-------

BooruPy is licensed under the terms of GPLv3_.

Documentation
-------------

You could call this a Documentation_.

Ehh, there is something like a test application
-----------------------------------------------

The test application is a simple image downloader, but beware my provider list could contain NSFW content.

.. _BooruPy: http://github.com/Kasoki/BooruPy
.. _BooruPyLoadr: http://github.com/Kasoki/BooruPy-Loadr
.. _Documentation: https://github.com/Kasoki/BooruPy/wiki/Documentation
.. _GPLv3: http://www.gnu.org/copyleft/gpl.html
